/*
 * Copyright (c) 2009 Lukas Mejdrech
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * - The name of the author may not be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/** @addtogroup ip
 *  @{
 */

/**
 * @file
 */

#ifndef __NET_IP_H__
#define __NET_IP_H__

#include <ipc/ipc.h>

#include "../../include/sockaddr.h"
#include "../../include/device.h"

#include "../../structures/module_map.h"

typedef struct ip_netif	ip_netif_t;
typedef ip_netif_t *	ip_netif_ref;

typedef struct ip_proto	ip_proto_t;
typedef ip_proto_t *	ip_proto_ref;

typedef struct ip_globals	ip_globals_t;

DEVICE_MAP_DECLARE( ip_netifs, ip_netif_t )

INT_MAP_DECLARE( ip_protos, ip_proto_t )

struct	ip_netif{
	device_id_t	device_id;
	int			phone;
	module_ref	arp;
	int			ipv;
	int			dhcp;
	in_addr_t	address;
	in_addr_t	netmask;
	in_addr_t	gateway;
	in_addr_t	broadcast;
	in_addr_t	dns1;
	in_addr_t	dns2;
	// TODO modules
};

struct ip_proto{
	int	protocol;
	int	phone;
};

struct	ip_globals{
	int		networking_phone;
	ip_netifs_t	netifs;
	ip_protos_t	protos;
	modules_t	modules;
};

#endif

/** @}
 */
